@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -31,8 +31,8 @@ public:
     explicit ContactGrantleeImObject(const QString &type, const QString &address, QObject *parent = nullptr);
     ~ContactGrantleeImObject();
 
-    QString type() const;
-    QString address() const;
+    Q_REQUIRED_RESULT QString type() const;
+    Q_REQUIRED_RESULT QString address() const;
 
 private:
     QString mType;
